part of 'index.dart';

class VidImageView extends StatefulWidget {
  const VidImageView({
    Key? key,
    required this.url,
    this.width,
    this.height,
    this.controller,
    this.errorBuilder,
    this.loadingBuilder,
    this.fit,
    this.alignment = Alignment.center,
    this.scale = 1.0,
  }) : super(key: key);

  final String url;
  final double? width;
  final double? height;
  final VidImageViewController? controller;
  final Widget Function(BuildContext context)? loadingBuilder;
  final ImageErrorWidgetBuilder? errorBuilder;
  final BoxFit? fit;
  final Alignment alignment;
  final double scale;

  @override
  State<StatefulWidget> createState() => _VidImageViewState();
}

class _VidImageViewState extends State<VidImageView> {
  static const backgroundColor = Colors.black;

  late final VidImageViewController controller;

  @override
  void initState() {
    controller = widget.controller ?? VidImageViewController();
    controller._bind(this);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return FutureBuilder(
      future: loadImage(),
      builder: (context, snapshot) {
        Widget child;
        if (snapshot.connectionState == ConnectionState.done) {
          if (snapshot.hasData && snapshot.data != null) {
            final buffer = snapshot.data as Uint8List?;
            child = Image.memory(
              buffer!,
              width: widget.width,
              height: widget.height,
              fit: widget.fit,
              alignment: widget.alignment,
              isAntiAlias: true,
              gaplessPlayback: true,
              scale: widget.scale,
            );
          } else {
            child = widget.errorBuilder != null
                ? widget.errorBuilder!(
                    context,
                    Exception("Vid Image load fail."),
                    snapshot.stackTrace,
                  )
                : ErrorWidget("Error");
          }
        } else {
          final loadingWidget = widget.loadingBuilder != null
              ? widget.loadingBuilder!(context)
              : const SizedBox(
                  width: 16,
                  height: 16,
                  child: CircularProgressIndicator(
                    strokeWidth: 2,
                    color: Colors.white,
                  ),
                );
          child = Center(child: loadingWidget);
        }

        return Container(
          color: backgroundColor,
          alignment: widget.alignment,
          width: widget.width,
          height: widget.height,
          child: child,
        );
      },
    );
  }

  Future<Uint8List?> loadImage() async {
    await Future.delayed(const Duration(seconds: 2));
    if (await controller.loadSource()) {
      return await controller.getImageBytes();
    }
    return null;
  }

  @override
  void dispose() {
    controller._release();
    super.dispose();
  }
}
