// https://pub.flutter-io.cn/packages/flutter_typeahead
import 'package:fis_ui/index.dart';
import 'package:fis_ui/types/index.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:flutter_typeahead/flutter_typeahead.dart';

/// 带建议选项输入框
class FSuggesionInput<T> extends StatelessWidget {
  FSuggesionInput({
    Key? key,
    required this.optionItemBuilder,
    required this.optionItemsFetcher,
    required this.onOptionSelected,
    this.debounceDuration = const Duration(milliseconds: 300),
    this.inputFieldConfiguration,
  }) : super(key: key);

  /// 可选项组件建造器
  final DataWidgetBuilder<T> optionItemBuilder;

  /// 建议数据获取方法
  final DataListBuilderWithParameter<T, String> optionItemsFetcher;

  /// 可选项选中回调
  final ValueCallback<T> onOptionSelected;

  /// 防抖限时
  final Duration debounceDuration;

  final FSuggesionInputFieldConfiguration? inputFieldConfiguration;

  @override
  Widget build(BuildContext context) {
    final c = inputFieldConfiguration;
    return TypeAheadField<T>(
      itemBuilder: (context, itemData) => optionItemBuilder(context, itemData),
      onSuggestionSelected: (T suggestion) => onOptionSelected(suggestion),
      suggestionsCallback: (String pattern) => optionItemsFetcher(pattern),
      debounceDuration: debounceDuration,
      textFieldConfiguration: TextFieldConfiguration(
        decoration: c?.decoration ?? FInput.borderDecoration(),
        inputFormatters: c?.inputFormatters,
        onChanged: c?.onChanged,
        controller: c?.controller,
        focusNode: c?.focusNode,
        enabled: c?.enabled == true,
        autofocus: c?.autofocus == true,
        maxLength: c?.maxLength,
        style: c?.style ??
            TextStyle(
              color: FInput.txtColor,
              fontSize: FInput.contentSize,
            ),
      ),
    );
  }
}

/// 输入框选项 同 TextField
class FSuggesionInputFieldConfiguration {
  FSuggesionInputFieldConfiguration({
    this.inputFormatters,
    this.controller,
    this.focusNode,
    this.enabled = true,
    this.autofocus = false,
    this.maxLength,
    this.onChanged,
    this.decoration,
    this.style,
  });
  final List<TextInputFormatter>? inputFormatters;
  final TextEditingController? controller;
  final FocusNode? focusNode;
  final bool enabled;
  final bool autofocus;
  final int? maxLength;
  final ValueChanged<String>? onChanged;
  final InputDecoration? decoration;
  final TextStyle? style;
}
