import 'package:fis_theme/theme.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';

class FPrimaryButton extends StatelessWidget {
  FPrimaryButton({
    Key? key,
    this.onPressed,
    this.onLongPressed,
    this.child,
    this.text,
    this.textSize,
    this.focusNode,
    this.autofocus = false,
    this.height,
    this.width,
    this.elevation = 0,
    this.color,
  }) : super(key: key);

  final VoidCallback? onPressed;
  final VoidCallback? onLongPressed;
  final Widget? child;
  final String? text;
  final double? textSize;
  final double? height;
  final double? width;
  final FocusNode? focusNode;
  final bool autofocus;
  final Color? color;
  final double elevation;

  static const _txtColor = Colors.white;
  static const _txtSize = 14.0;

  @override
  Widget build(BuildContext context) {
    const borderRadius = BorderRadius.all(Radius.circular(8));
    final style = ElevatedButton.styleFrom(
      primary: color ?? FTheme.ins.colorScheme.buttonPrimary,
      elevation: elevation,
      maximumSize: Size.infinite,
      shape: const RoundedRectangleBorder(borderRadius: borderRadius),
    );

    final btn = ElevatedButton(
      onPressed: onPressed,
      onLongPress: onLongPressed,
      child: _buildChild(),
      focusNode: focusNode,
      autofocus: autofocus,
      style: style,
    );
    BoxConstraints? constraints;
    if (width == null) {
      constraints = const BoxConstraints(
        minWidth: 195,
      );
    }
    return Container(
      height: height ?? 32,
      width: width,
      constraints: constraints,
      child: btn,
    );
  }

  Widget? _buildChild() {
    if (child != null) return child;
    if (text != null && text!.isNotEmpty) {
      return Text(
        text!,
        style: TextStyle(color: _txtColor, fontSize: textSize ?? _txtSize),
      );
    }
    return null;
  }
}

class FSecondaryButton extends StatelessWidget {
  FSecondaryButton({
    Key? key,
    this.onPressed,
    this.onLongPressed,
    this.child,
    this.text,
    this.textSize,
    this.focusNode,
    this.autofocus = false,
    this.height,
    this.width,
    this.elevation = 0,
    this.color,
  }) : super(key: key);

  final VoidCallback? onPressed;
  final VoidCallback? onLongPressed;
  final Widget? child;
  final String? text;
  final double? textSize;
  final double? height;
  final double? width;
  final FocusNode? focusNode;
  final bool autofocus;
  final Color? color;
  final double elevation;

  bool get _disabled => onPressed == null && onLongPressed == null;

  static const _borderColor = Color(0xffbababa);
  static const _txtColor = Color(0xff4c4948);
  static const _txtSize = 14.0;

  @override
  Widget build(BuildContext context) {
    const borderRadius = BorderRadius.all(Radius.circular(8));
    final style = OutlinedButton.styleFrom(
      primary: color ?? FTheme.ins.colorScheme.buttonPrimary,
      elevation: elevation,
      maximumSize: Size.infinite,
      shape: const RoundedRectangleBorder(
        borderRadius: borderRadius,
        side: BorderSide(
          width: 1,
          color: _borderColor,
        ),
      ),
    );

    final btn = OutlinedButton(
      onPressed: onPressed,
      onLongPress: onLongPressed,
      child: _buildChild(),
      focusNode: focusNode,
      autofocus: autofocus,
      style: style,
    );
    BoxConstraints? constraints;
    if (width == null) {
      constraints = const BoxConstraints(
        minWidth: 195,
      );
    }
    return Container(
      height: height ?? 32,
      width: width,
      constraints: constraints,
      child: btn,
    );
  }

  Widget _buildChild() {
    if (child != null) return child!;
    if (text != null && text!.isNotEmpty) {
      final txtStyle =
          TextStyle(color: _txtColor, fontSize: textSize ?? _txtSize);
      return Text(
        text!,
        style: _disabled ? txtStyle.copyWith(color: _borderColor) : txtStyle,
      );
    }
    return Container();
  }
}
