import 'package:flutter/foundation.dart';
import 'package:flutter/widgets.dart';

import 'sizer_stub.dart'
    if (dart.library.io) 'sizer_io.dart'
    if (dart.library.js) 'sizer_web.dart';

typedef ResizeEventCallback = void Function(Size size);

abstract class Sizer {
  static Sizer? _internal;

  static SizerJudgment? _judgment;

  static Sizer get ins {
    if (_internal == null)
      throw UnimplementedError("Must call Sizer.init() before.");
    return _internal!;
  }

  static Sizer init([SizerJudgment judgment = const SizerJudgment()]) {
    _judgment = judgment;
    _internal = kIsWeb ? SizerWeb() : SizerNative();
    ins._handleInit();
    return ins;
  }

  SizerJudgment get judgment => _judgment!;

  @protected
  Set<ResizeEventCallback>? resizeCallbacks;

  @protected
  MediaQueryData? mediaQueryData;

  /// 尺寸
  Size get size => mediaQueryData?.size ?? Size.zero;

  /// 是否移动端
  bool get isMobile;

  void addListener(ResizeEventCallback callback) {
    resizeCallbacks ??= {};
    resizeCallbacks!.add(callback);
  }

  void removeListener(ResizeEventCallback callback) {
    resizeCallbacks?.remove(callback);
  }

  @protected
  void beginListenResize();

  @protected
  void handleResize() {
    loadSize();
    notifyResize();
  }

  @protected
  void notifyResize() {
    if (resizeCallbacks == null || resizeCallbacks!.isEmpty) return;
    for (final callback in resizeCallbacks!) {
      callback.call(size);
    }
  }

  void _handleInit() {
    loadSize();
    beginListenResize();
  }

  @protected
  void loadSize() {
    mediaQueryData = MediaQueryData.fromWindow(WidgetsBinding.instance!.window);
  }
}

class SizerJudgment {
  const SizerJudgment({
    this.minDesktopWidth = 1200.0,
    this.minDesktopHeight = 675.0,
    this.minMobileWidth = 280.0,
    this.minMobileHeight = 440.0,
  });
  final double minMobileWidth;
  final double minMobileHeight;
  final double minDesktopWidth;
  final double minDesktopHeight;
}
