import 'package:fis_ui/define.dart';
import 'package:flutter/gestures.dart';
import 'package:flutter/widgets.dart';

/// 单子组件可滚动视图
class FSingleChildScrollView extends SingleChildScrollView implements FWidget {
  /// 单子组件可滚动视图
  ///
  /// [padding] 内间距
  ///
  /// [primary] 指是否使用widget树中默认的[PrimaryScrollController];
  /// 当滑动方向为垂直方向（[scrollDirection]值为[Axis.vertical]）并且没有指定[controller]时，[primary]默认为[true].
  ///
  /// [physics] 设置滚动效果，类型[ScrollPhysics]
  ///
  /// [controller] 可以控制滚动的位置当; [primary]为[true]时，[controller]必须为[null]，类型[ScrollController].
  ///
  /// [child] 子组件
  ///
  /// [restorationId] 状态恢复Id
  ///
  /// [reverse] 启用翻转
  ///
  /// [scrollDirection] 滚动方向，默认垂直
  ///
  /// [dragStartBehavior] 处理拖动开始行为的方式
  ///
  /// [clipBehavior] 裁剪行为
  const FSingleChildScrollView({
    Key? key,
    EdgeInsetsGeometry? padding,
    bool? primary,
    ScrollPhysics? physics,
    ScrollController? controller,
    FWidget? child,
    String? restorationId,
    bool reverse = false,
    Axis scrollDirection = Axis.vertical,
    DragStartBehavior dragStartBehavior = DragStartBehavior.start,
    Clip clipBehavior = Clip.hardEdge,
  }) : super(
          key: key,
          padding: padding,
          primary: primary,
          physics: physics,
          controller: controller,
          child: child,
          restorationId: restorationId,
          reverse: reverse,
          scrollDirection: scrollDirection,
          dragStartBehavior: dragStartBehavior,
          clipBehavior: clipBehavior,
        );
}
