import 'package:flutter/widgets.dart';

import '../define.dart';

/// 文本组件
class FText extends Text implements FWidget {
  /// 文本组件
  ///
  /// [data] 文本数据
  ///
  /// [style] 文本样式
  ///
  /// [textAlign] 文字对齐方式
  ///
  /// [overflow] 文字溢出处理
  const FText(
    this.data, {
    Key? key,
    this.style,
    this.textAlign,
    this.maxLines,
    this.overflow,
  }) : super(data);

  final String data;
  final TextStyle? style;
  final TextAlign? textAlign;
  final int? maxLines;
  final TextOverflow? overflow;
}

/// 富文本组件
class FRichText extends Text implements FWidget {
  /// 富文本组件
  ///
  /// [textSpan] 内联文本组件，接受[InlineSpan]的实现组件，如[TextSpan]、[WidgetSpan]
  ///
  /// [style] 文本样式
  ///
  /// [textAlign] 文字对齐方式
  ///
  /// [overflow] 文字溢出处理
  const FRichText(
    this.textSpan, {
    Key? key,
    this.style,
    this.textAlign,
    this.maxLines,
    this.overflow,
  }) : super.rich(textSpan);

  final InlineSpan textSpan;
  final TextStyle? style;
  final TextAlign? textAlign;
  final int? maxLines;
  final TextOverflow? overflow;
}
